@@ -5,7 +5,7 @@
 "world" <- function(ylim = c(-90, 90), xlim = NULL, 
     add = FALSE, asp = 1, xlab = "", ylab = "", xaxt = "n", yaxt = "n", 
     eps = 0.1, col = 1, shift = FALSE, fill = FALSE, col.water = "white", 
-    col.land = "darkgrey", ...) {
+    col.land = "darkgrey",alpha=NA, ...) {
     #
     # load world data set of land outlines
     # (should not reload if it is already loaded)
@@ -14,6 +14,8 @@
     if (shift & fill) {
         stop("filling in land not implemented with shift option")
     }
+    # reset colors with alpha value
+   
     if (shift) {
         ind1 <- !is.na(world.dat$x)
         ind2 <- (world.dat$x < 0)
@@ -61,8 +63,10 @@ world.color <- function(obj,xlim = c(-180, 180), ylim = c(-90,
     # first add ocean color as background
     # find the size of current region but don't let it get bigger than
     #lon lat range
-    rect(xlim[1], ylim[1], xlim[2], ylim[2], col = col.water, 
-        border = NA)
+    #if(!no.ocean){
+    #rect(xlim[1], ylim[1], xlim[2], ylim[2], col = col.water, 
+    #    border = NA)}
+    
     # find separate polygons of land masses and islands in world.dat
     # these are indicated by NA's
     ind <- (1:length(obj$x))[is.na(obj$x)]
@@ -95,6 +99,46 @@ world.color <- function(obj,xlim = c(-180, 180), ylim = c(-90,
         }
     }
 }
+world.land <- function( col.water = "white", col.land = "darkgrey",alpha=NA, ...) {
+    data(world.dat)
+    obj<- world.dat
+     if( !is.na( alpha) ){
+    #    
+      col.water<- rgb( t(col2rgb(col.water, TRUE)), alpha=255*alpha, maxColorValue=255)
+      col.land<-  rgb( t(col2rgb(col.land, TRUE)), alpha=255*alpha, maxColorValue=255)
+    }
+    # find separate polygons of land masses and islands in world.dat
+    # these are indicated by NA's
+    ind <- (1:length(obj$x))[is.na(obj$x)]
+    ind <- c(1, ind)
+    N <- length(ind) - 1
+    lakes.id <- c(46, 53, 25, 26, 28, 27, 4, 47, 48, 51, 49, 
+        50)
+    land.id <- (1:N)[-lakes.id]
+    # loop through polygons of land
+   
+        for (k in land.id) {
+            tempi <- ind[k]:ind[k + 1]
+            polygon(list(x = obj$x[tempi], y = obj$y[tempi]), 
+                col = col.land, border = col.land, ...)
+        }
+    
+    #
+    # add in interior of antarctica as a
+    # rectangle below farthest south coastline
+    ytemp <- obj$y[ind[21] + 1]
+    rect(-180, -90, 180, ytemp, col = col.land, border = col.land, 
+        ...)
+    # loop through polygons of lakes do this second so
+    # color over writes the land
+   
+        for (k in lakes.id) {
+            tempi <- ind[k]:ind[k + 1]
+            polygon(list(x = obj$x[tempi], y = obj$y[tempi]), 
+                col = col.water, border = col.water, ...)
+        }
+    
+}
 
 in.land.grid<- function (grid.list)
 {
